==> rxmicro-annotation-processor-documentation-0.5-sources.jar: io/rxmicro/annotation/processor/documentation/component/HttpResponseExampleBuilder.java <==
/*
 * Copyright (c) 2020. https://rxmicro.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.rxmicro.annotation.processor.documentation.component;

import io.rxmicro.annotation.processor.rest.server.model.RestControllerClassStructureStorage;
import io.rxmicro.annotation.processor.rest.server.model.RestControllerMethod;
import io.rxmicro.documentation.ResourceDefinition;

import java.util.Optional;

/**
 * @author nedis
 * @since 0.1
 */
public interface HttpResponseExampleBuilder {

    String build(ResourceDefinition resourceDefinition,
                 RestControllerClassStructureStorage restControllerClassStructureStorage,
                 RestControllerMethod method);

    String buildErrorExample(ResourceDefinition resourceDefinition,
                             int statusCode,
                             String message);

    String buildErrorExample(ResourceDefinition resourceDefinition,
                             int statusCode);

    Optional<String> getJsonBodyExample(RestControllerClassStructureStorage restControllerClassStructureStorage,
                                        RestControllerMethod method);
}

==> rxmicro-annotation-processor-documentation-0.7-sources.jar: io/rxmicro/annotation/processor/documentation/component/HttpResponseExampleBuilder.java <==
/*
 * Copyright (c) 2020. https://rxmicro.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.rxmicro.annotation.processor.documentation.component;

import io.rxmicro.annotation.processor.rest.model.RestObjectModelClass;
import io.rxmicro.annotation.processor.rest.server.model.RestControllerClassStructureStorage;
import io.rxmicro.annotation.processor.rest.server.model.RestControllerMethod;
import io.rxmicro.documentation.ResourceDefinition;

import java.util.Optional;

/**
 * @author nedis
 * @since 0.1
 */
public interface HttpResponseExampleBuilder {

    String build(ResourceDefinition resourceDefinition,
                 RestControllerClassStructureStorage restControllerClassStructureStorage,
                 RestControllerMethod method);

    String build(ResourceDefinition resourceDefinition,
                 int statusCode,
                 RestObjectModelClass restObjectModelClass);

    String buildErrorExample(ResourceDefinition resourceDefinition,
                             int statusCode,
                             String message);

    String buildErrorExample(ResourceDefinition resourceDefinition,
                             int statusCode);

    Optional<String> getJsonBodyExample(RestControllerClassStructureStorage restControllerClassStructureStorage,
                                        RestControllerMethod method);
}
